@@ -11,7 +11,7 @@ class Name_That_Hash:
         self.prototypes = list(prototypes)
 
     def identify(self, chash: str):
-        logger.trace(chash)
+        logger.debug(chash)
         chash = chash.strip()
         output = []
         for prototype in self.prototypes:
