@@ -6,10 +6,6 @@ import base64
 from rich import print, text
 from loguru import logger
 
-logger.add(
-    sys.stderr, format="{time} {level} {message}", filter="my_module", level="INFO"
-)
-
 from name_that_hash import hash_namer, hashes, prettifier
 
 from name_that_hash import check_hashes
